@@ -45,7 +45,7 @@ def clean_id(input):
     replace whitespace by _ (underscore)
     '''
     input = re.sub(r'[^A-Za-z0-9\s]+', '', input)
-    input = re.sub("\s", "_", input)
+    input = re.sub(r"\s", "_", input)
     input = input.lower()
     return input
 
